@@ -56,7 +56,7 @@ class type_fields:  # noqa: N801
 
         to_csv(..., fields=type_fields('file', 'link'))
         # supplying two types at once is equivalent to supplying two separate type_fields
-        to_csv(..., fields=[type_fields('file'), type_fields('link'))
+        to_csv(..., fields=[type_fields('file'), type_fields('link')])
 
     Both forms would result in headers like ``file.createdOn`` and
     ``link.target`` in the resulting export file.
@@ -81,7 +81,7 @@ class data_stream:  # noqa: N801
 
     .. code-block:: python
 
-        to_csv(..., fields=data_stream('plain', fallback_encoding='ascii')
+        to_csv(..., fields=data_stream('plain', fallback_encoding='ascii'))
 
     Encoding errors will result in replacement characters — ?'s — in the output
     CSV. The fallback encoding is unset by default, resulting in *no data* in
@@ -194,7 +194,7 @@ def to_csv(traces, output, fields,
                            # include all model-defined metadata fields for email traces
                            type_fields('email'),
                            # include the first kilobyte of data from the plain data stream (converted to text)
-                           data_stream('plain', max_size=1024)
+                           data_stream('plain', max_size=1024)])
 
         The exported file with have the explicitly provided fields like ``uid``
         and ``name``, but also fields from property names generated from the
