@@ -282,6 +282,13 @@ class Vector(Sequence):
         # (unpack always returns a tuple, we always need the first and only element)
         return self._struct.unpack_from(self._raw, offset=item * size)[0]
 
+    def __eq__(self, other):
+        # define equality as the same type and identical data
+        return isinstance(other, Vector) and self._raw == other._raw
+
+    def __hash__(self):
+        return hash((13, self._raw))  # avoid a hash collision with the hash of _raw
+
     def __bytes__(self):
         return self._raw
 
